"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAnimation = void 0;
/* eslint-disable @typescript-eslint/no-explicit-any */
var react_1 = require("react");
function useAnimation(params) {
    var rootRef = react_1.useRef(null);
    var animationDelay = params.animationDelay, animationDuration = params.animationDuration, rootMargin = params.rootMargin, animationType = params.animationType;
    function fade() {
        if (!rootRef.current) {
            return;
        }
        var ref = rootRef.current;
        var style = ref.style;
        style.opacity = "0%";
        var observe = function () {
            var observer = new IntersectionObserver(function (entries) {
                if (entries[0].isIntersecting) {
                    style.transition = "opacity " + (animationDuration !== null && animationDuration !== void 0 ? animationDuration : 300) + "ms";
                    style.transitionDelay = (animationDelay !== null && animationDelay !== void 0 ? animationDelay : 0) + "ms";
                    style.opacity = "100%";
                    style.transitionTimingFunction = "ease-in-out";
                    observer.unobserve(entries[0].target);
                    window.removeEventListener("load", observe);
                    return;
                }
            }, { rootMargin: rootMargin });
            observer.observe(ref);
        };
        window.addEventListener("load", observe);
    }
    function fadeFromDirection(params) {
        var direction = params.direction;
        if (!rootRef.current) {
            return;
        }
        var ref = rootRef.current;
        var style = ref.style;
        style.opacity = "0%";
        style.transform = (function () {
            switch (direction) {
                case "left":
                    return "translateX(-150px)";
                case "top":
                    return "translateY(-150px)";
                case "right":
                    return "translateX(150px)";
                case "bottom":
                    return "translateY(150px)";
                case "topLeft":
                    return "translate(-150px, -150px)";
                case "topRight":
                    return "translate(150px, -150px)";
                case "bottomLeft":
                    return "translate(-150px, 150px)";
                case "bottomRight":
                    return "translate(150px, 150px)";
                case undefined:
                    return "none";
            }
        })();
        var observe = function () {
            var observer = new IntersectionObserver(function (entries) {
                if (entries[0].isIntersecting) {
                    style.transition = (function () {
                        if (direction === undefined) {
                            return "opacity " + (animationDuration !== null && animationDuration !== void 0 ? animationDuration : 300) + "ms";
                        }
                        return [
                            "opacity 300ms,",
                            "transform " + (animationDuration !== null && animationDuration !== void 0 ? animationDuration : 300) + "ms",
                        ].join(" ");
                    })();
                    style.transitionDelay = (animationDelay !== null && animationDelay !== void 0 ? animationDelay : 0) + "ms";
                    style.opacity = "100%";
                    if (direction !== undefined) {
                        style.transform = "none";
                    }
                    style.transitionTimingFunction = "ease-in-out";
                    observer.unobserve(entries[0].target);
                    window.removeEventListener("load", observe);
                    return;
                }
            }, { rootMargin: rootMargin });
            observer.observe(ref);
        };
        window.addEventListener("load", observe);
    }
    var animate = (function () {
        switch (animationType) {
            case "fade":
                return fade;
            case "fadeFromDirection":
                return fadeFromDirection;
        }
    })();
    return { rootRef: rootRef, animate: animate };
}
exports.useAnimation = useAnimation;
//# sourceMappingURL=useAnimation.js.map